@@ -29,7 +29,7 @@
 # referenced as a library via a require statement, but it can be
 # distributed independently as an application.
 
-RAKEVERSION = '0.5.3'
+RAKEVERSION = '0.5.4'
 
 require 'rbconfig'
 require 'ftools'
@@ -651,13 +651,8 @@ end
 # module, but mark them private so that they don't unintentionally
 # define methods on other objects.
 
-file_utils_methods = (FileUtils.methods - Object.methods)
 include RakeFileUtils
-
-file_utils_methods.each do |name|
-  private name.to_sym
-end
-file_utils_methods = nil
+private(*FileUtils.instance_methods(false))
 
 ######################################################################
 module Rake
@@ -789,7 +784,13 @@ module Rake
     #
     def include(*filenames)
       # TODO: check for pending
-      filenames.each do |fn| @pending_add << fn end
+      filenames.each do |fn|
+	if fn.respond_to? :to_ary
+	  include(*fn.to_ary)
+	else
+	  @pending_add << fn
+	end
+      end
       @pending = true
       self
     end
@@ -994,6 +995,7 @@ module Rake
 
     DEFAULT_IGNORE_PATTERNS = [
       /(^|[\/\\])CVS([\/\\]|$)/,
+      /(^|[\/\\])\.svn([\/\\]|$)/,
       /\.bak$/,
       /~$/,
       /(^|[\/\\])core$/
@@ -1016,6 +1018,7 @@ module Rake
       # Set the ignore patterns back to the default value.  The
       # default patterns will ignore files 
       # * containing "CVS" in the file path
+      # * containing ".svn" in the file path
       # * ending with ".bak"
       # * ending with "~"
       # * named "core"
