@@ -36,6 +36,23 @@ class TestFileList < Test::Unit::TestCase
       fl.sort
   end
 
+  def test_create_with_brackets_and_filelist
+    fl = FileList[FileList["testdata/*.c", "x"]]
+    assert_equal ["testdata/abc.c", "testdata/x.c", "testdata/xyz.c", "x"].sort,
+      fl.sort
+  end
+
+  def test_include_with_another_array
+    fl = FileList.new.include(["x", "y", "z"])
+    assert_equal ["x", "y", "z"].sort, fl.sort
+  end
+
+  def test_include_with_another_filelist
+    fl = FileList.new.include(FileList["testdata/*.c", "x"])
+    assert_equal ["testdata/abc.c", "testdata/x.c", "testdata/xyz.c", "x"].sort,
+      fl.sort
+  end
+
   def test_append
     fl = FileList.new
     fl << "a.rb" << "b.rb"
@@ -227,6 +244,7 @@ class TestFileList < Test::Unit::TestCase
   def test_ignore_special
     f = FileList['testdata/*']
     assert ! f.include?("testdata/CVS"), "Should not contain CVS"
+    assert ! f.include?("testdata/.svn"), "Should not contain .svn"
     assert ! f.include?("testdata/.dummy"), "Should not contain dot files"
     assert ! f.include?("testdata/x.bak"), "Should not contain .bak files"
     assert ! f.include?("testdata/x~"), "Should not contain ~ files"
@@ -234,11 +252,12 @@ class TestFileList < Test::Unit::TestCase
   end
 
   def test_clear_ignore_patterns
-    f = FileList['testdata/*']
+    f = FileList['testdata/*', 'testdata/.svn']
     f.clear_exclude
     assert f.include?("testdata/abc.c")
     assert f.include?("testdata/xyz.c")
     assert f.include?("testdata/CVS")
+    assert f.include?("testdata/.svn")
     assert f.include?("testdata/x.bak")
     assert f.include?("testdata/x~")
   end
@@ -247,6 +266,8 @@ class TestFileList < Test::Unit::TestCase
     fl = FileList.new
     assert fl.exclude?("x/CVS/y")
     assert fl.exclude?("x\\CVS\\y")
+    assert fl.exclude?("x/.svn/y")
+    assert fl.exclude?("x\\.svn\\y")
     assert fl.exclude?("x/core")
     assert fl.exclude?("x\\core")
   end
@@ -256,6 +277,8 @@ class TestFileList < Test::Unit::TestCase
     fl.exclude(/~\d+$/)
     assert fl.exclude?("x/CVS/y")
     assert fl.exclude?("x\\CVS\\y")
+    assert fl.exclude?("x/.svn/y")
+    assert fl.exclude?("x\\.svn\\y")
     assert fl.exclude?("x/core")
     assert fl.exclude?("x\\core")
     assert fl.exclude?("x/abc~1")
@@ -427,6 +450,7 @@ class TestFileList < Test::Unit::TestCase
     verbose(false) do
       mkdir "testdata" unless File.exist? "testdata"
       mkdir "testdata/CVS" rescue nil
+      mkdir "testdata/.svn" rescue nil
       touch "testdata/.dummy"
       touch "testdata/x.bak"
       touch "testdata/x~"
